﻿// ----------------------------------------------------------------------------------
//
// Copyright Microsoft Corporation
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ----------------------------------------------------------------------------------

using System;
using System.Management.Automation;
using Microsoft.WindowsAzure.Commands.Utilities.Properties;

namespace Microsoft.WindowsAzure.Commands.Utilities.Store
{
    [AttributeUsage(AttributeTargets.Property | AttributeTargets.Field)]
    public sealed class ValidateCountryLengthAttribute : ValidateEnumeratedArgumentsAttribute
    {
        const int MaxLength = 2;

        const int MinLength = 2;

        protected override void ValidateElement(object element)
        {
            string country = (string)element;

            if (country.Length > MaxLength || country.Length < MinLength)
            {
                throw new ArgumentException(Resources.InvalidCountryNameMessage);
            }
        }
    }
}
